--- nagios-plugins-1.5/plugins/check_http.c	2013-10-02 11:22:21.000000000 -0400
+++ check_http_ttfb.c	2013-12-23 12:50:07.691132878 -0500
@@ -31,6 +31,7 @@
 *
 *****************************************************************************/
 
+
 /* splint -I. -I../../plugins -I../../lib/ -I/usr/kerberos/include/ ../../plugins/check_http.c */
 
 const char *progname = "check_http";
@@ -116,6 +117,7 @@ int onredirect = STATE_OK;
 int followsticky = STICKY_NONE;
 int use_ssl = FALSE;
 int use_sni = FALSE;
+int use_ttfb = FALSE;
 int verbose = FALSE;
 int show_extended_perfdata = FALSE;
 int sd;
@@ -237,6 +239,7 @@ process_arguments (int argc, char **argv
     {"use-ipv4", no_argument, 0, '4'},
     {"use-ipv6", no_argument, 0, '6'},
     {"extended-perfdata", no_argument, 0, 'E'},
+    {"time-to-firstbyte", no_argument, 0, 'F'},
     {0, 0, 0, 0}
   };
 
@@ -257,7 +260,7 @@ process_arguments (int argc, char **argv
   }
 
   while (1) {
-    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:j:T:I:a:b:d:e:p:s:R:r:u:f:C:J:K:nlLS::m:M:N:E", longopts, &option);
+    c = getopt_long (argc, argv, "Vvh46t:c:w:A:k:H:P:j:T:I:a:b:d:e:p:s:R:r:u:f:C:J:K:nlLS::m:M:N:E:F", longopts, &option);
     if (c == -1 || c == EOF)
       break;
 
@@ -513,9 +516,11 @@ process_arguments (int argc, char **argv
     case 'E': /* show extended perfdata */
       show_extended_perfdata = TRUE;
       break;
-    }
+    case 'F': /* Use first byte time for thresholds */
+      use_ttfb = TRUE;
+      break;
   }
-
+}
   c = optind;
 
   if (server_address == NULL && c < argc)
@@ -1190,9 +1195,12 @@ check_http (void)
 
   /* check elapsed time */
   if (show_extended_perfdata)
-    xasprintf (&msg,
-           _("%s - %d bytes in %.3f second response time %s|%s %s %s %s %s %s %s"),
-           msg, page_len, elapsed_time,
+   xasprintf (&msg,
+           use_ttfb ? _("%s - %sTime to first byte is %.3f %s|%s %s %s %s %s %s %s"):
+             _("%s - %d bytes in %.3f second response time %s|%s %s %s %s %s %s %s"),
+           msg, 
+           use_ttfb ? "": page_len,
+           use_ttfb ? elapsed_time_firstbyte: elapsed_time_connect,
            (display_html ? "</A>" : ""),
            perfd_time (elapsed_time),
            perfd_size (page_len),
@@ -1203,13 +1211,19 @@ check_http (void)
            perfd_time_transfer (elapsed_time_transfer));
   else
     xasprintf (&msg,
-           _("%s - %d bytes in %.3f second response time %s|%s %s"),
-           msg, page_len, elapsed_time,
+           use_ttfb ? _("%s - %sTime to first byte is %.3f %s|%s %s"):
+             _("%s - %d bytes in %.3f second response time %s|%s %s"),
+           msg, 
+           use_ttfb ? "": page_len, 
+           use_ttfb ? elapsed_time_firstbyte: elapsed_time,
            (display_html ? "</A>" : ""),
-           perfd_time (elapsed_time),
+           use_ttfb ? perfd_time_firstbyte (elapsed_time_firstbyte) : perfd_time (elapsed_time),
            perfd_size (page_len));
 
-  result = max_state_alt(get_status(elapsed_time, thlds), result);
+    if (use_ttfb)
+     result = max_state_alt(get_status(elapsed_time_firstbyte, thlds), result);
+   else 
+     result = max_state_alt(get_status(elapsed_time, thlds), result);
 
   die (result, "HTTP %s: %s\n", state_text(result), msg);
   /* die failed? */
@@ -1389,7 +1403,9 @@ server_port_check (int ssl_flag)
 }
 
 char *perfd_time (double elapsed_time)
-{
+{ if (use_ttfb)
+  return fperfdata("time", elapsed_time, "s", FALSE, 0, FALSE, 0, FALSE, 0, FALSE, 0);
+  else
   return fperfdata ("time", elapsed_time, "s",
             thlds->warning?TRUE:FALSE, thlds->warning?thlds->warning->end:0,
             thlds->critical?TRUE:FALSE, thlds->critical?thlds->critical->end:0,
@@ -1412,8 +1428,13 @@ char *perfd_time_headers (double elapsed
 }
 
 char *perfd_time_firstbyte (double elapsed_time_firstbyte)
-{
-  return fperfdata ("time_firstbyte", elapsed_time_firstbyte, "s", FALSE, 0, FALSE, 0, FALSE, 0, FALSE, 0);
+{ if (use_ttfb)
+      return fperfdata ("time_firstbyte", elapsed_time_firstbyte, "s",
+            thlds->warning?TRUE:FALSE, thlds->warning?thlds->warning->end:0,
+            thlds->critical?TRUE:FALSE, thlds->critical?thlds->critical->end:0,
+                   TRUE, 0, FALSE, 0);
+    else
+      return fperfdata ("time_firstbyte", elapsed_time_firstbyte, "s", FALSE, 0, FALSE, 0, FALSE, 0, FALSE, 0);
 }
 
 char *perfd_time_transfer (double elapsed_time_transfer)
@@ -1531,7 +1552,8 @@ print_help (void)
   printf ("    %s\n", _("specified IP address. stickyport also ensures port stays the same."));
   printf (" %s\n", "-m, --pagesize=INTEGER<:INTEGER>");
   printf ("    %s\n", _("Minimum page size required (bytes) : Maximum page size required (bytes)"));
-
+  printf (" %s\n", "-F, --time-to-firstbyte");
+  printf ("    %s\n", _("Cause -w and -c to act on time to first byte."));
   printf (UT_WARN_CRIT);
 
   printf (UT_TIMEOUT, DEFAULT_SOCKET_TIMEOUT);
